==> vtk6-6.3.0-4-armv7h.pkg.tar.xz: vtk/vtkImplicitPlaneRepresentation.java <==
// java wrapper for vtkImplicitPlaneRepresentation object
//

package vtk;
import vtk.*;

public class vtkImplicitPlaneRepresentation extends vtkWidgetRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetOrigin_2(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_2(id0,id1,id2); }

  private native void SetOrigin_3(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_3(id0); }

  private native double[] GetOrigin_4();
  public double[] GetOrigin()
    { return GetOrigin_4(); }

  private native void GetOrigin_5(double id0[]);
  public void GetOrigin(double id0[])
    { GetOrigin_5(id0); }

  private native void SetNormal_6(double id0,double id1,double id2);
  public void SetNormal(double id0,double id1,double id2)
    { SetNormal_6(id0,id1,id2); }

  private native void SetNormal_7(double id0[]);
  public void SetNormal(double id0[])
    { SetNormal_7(id0); }

  private native void SetNormalToCamera_8();
  public void SetNormalToCamera()
    { SetNormalToCamera_8(); }

  private native double[] GetNormal_9();
  public double[] GetNormal()
    { return GetNormal_9(); }

  private native void GetNormal_10(double id0[]);
  public void GetNormal(double id0[])
    { GetNormal_10(id0); }

  private native void SetNormalToXAxis_11(int id0);
  public void SetNormalToXAxis(int id0)
    { SetNormalToXAxis_11(id0); }

  private native int GetNormalToXAxis_12();
  public int GetNormalToXAxis()
    { return GetNormalToXAxis_12(); }

  private native void NormalToXAxisOn_13();
  public void NormalToXAxisOn()
    { NormalToXAxisOn_13(); }

  private native void NormalToXAxisOff_14();
  public void NormalToXAxisOff()
    { NormalToXAxisOff_14(); }

  private native void SetNormalToYAxis_15(int id0);
  public void SetNormalToYAxis(int id0)
    { SetNormalToYAxis_15(id0); }

  private native int GetNormalToYAxis_16();
  public int GetNormalToYAxis()
    { return GetNormalToYAxis_16(); }

  private native void NormalToYAxisOn_17();
  public void NormalToYAxisOn()
    { NormalToYAxisOn_17(); }

  private native void NormalToYAxisOff_18();
  public void NormalToYAxisOff()
    { NormalToYAxisOff_18(); }

  private native void SetNormalToZAxis_19(int id0);
  public void SetNormalToZAxis(int id0)
    { SetNormalToZAxis_19(id0); }

  private native int GetNormalToZAxis_20();
  public int GetNormalToZAxis()
    { return GetNormalToZAxis_20(); }

  private native void NormalToZAxisOn_21();
  public void NormalToZAxisOn()
    { NormalToZAxisOn_21(); }

  private native void NormalToZAxisOff_22();
  public void NormalToZAxisOff()
    { NormalToZAxisOff_22(); }

  private native void SetLockNormalToCamera_23(int id0);
  public void SetLockNormalToCamera(int id0)
    { SetLockNormalToCamera_23(id0); }

  private native int GetLockNormalToCamera_24();
  public int GetLockNormalToCamera()
    { return GetLockNormalToCamera_24(); }

  private native void LockNormalToCameraOn_25();
  public void LockNormalToCameraOn()
    { LockNormalToCameraOn_25(); }

  private native void LockNormalToCameraOff_26();
  public void LockNormalToCameraOff()
    { LockNormalToCameraOff_26(); }

  private native void SetTubing_27(int id0);
  public void SetTubing(int id0)
    { SetTubing_27(id0); }

  private native int GetTubing_28();
  public int GetTubing()
    { return GetTubing_28(); }

  private native void TubingOn_29();
  public void TubingOn()
    { TubingOn_29(); }

  private native void TubingOff_30();
  public void TubingOff()
    { TubingOff_30(); }

  private native void SetDrawPlane_31(int id0);
  public void SetDrawPlane(int id0)
    { SetDrawPlane_31(id0); }

  private native int GetDrawPlane_32();
  public int GetDrawPlane()
    { return GetDrawPlane_32(); }

  private native void DrawPlaneOn_33();
  public void DrawPlaneOn()
    { DrawPlaneOn_33(); }

  private native void DrawPlaneOff_34();
  public void DrawPlaneOff()
    { DrawPlaneOff_34(); }

  private native void SetOutlineTranslation_35(int id0);
  public void SetOutlineTranslation(int id0)
    { SetOutlineTranslation_35(id0); }

  private native int GetOutlineTranslation_36();
  public int GetOutlineTranslation()
    { return GetOutlineTranslation_36(); }

  private native void OutlineTranslationOn_37();
  public void OutlineTranslationOn()
    { OutlineTranslationOn_37(); }

  private native void OutlineTranslationOff_38();
  public void OutlineTranslationOff()
    { OutlineTranslationOff_38(); }

  private native void SetOutsideBounds_39(int id0);
  public void SetOutsideBounds(int id0)
    { SetOutsideBounds_39(id0); }

  private native int GetOutsideBounds_40();
  public int GetOutsideBounds()
    { return GetOutsideBounds_40(); }

  private native void OutsideBoundsOn_41();
  public void OutsideBoundsOn()
    { OutsideBoundsOn_41(); }

  private native void OutsideBoundsOff_42();
  public void OutsideBoundsOff()
    { OutsideBoundsOff_42(); }

  private native void SetScaleEnabled_43(int id0);
  public void SetScaleEnabled(int id0)
    { SetScaleEnabled_43(id0); }

  private native int GetScaleEnabled_44();
  public int GetScaleEnabled()
    { return GetScaleEnabled_44(); }

  private native void ScaleEnabledOn_45();
  public void ScaleEnabledOn()
    { ScaleEnabledOn_45(); }

  private native void ScaleEnabledOff_46();
  public void ScaleEnabledOff()
    { ScaleEnabledOff_46(); }

  private native void GetPolyData_47(vtkPolyData id0);
  public void GetPolyData(vtkPolyData id0)
    { GetPolyData_47(id0); }

  private native long GetPolyDataAlgorithm_48();
  public vtkPolyDataAlgorithm GetPolyDataAlgorithm() {
    long temp = GetPolyDataAlgorithm_48();

    if (temp == 0) return null;
    return (vtkPolyDataAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void GetPlane_49(vtkPlane id0);
  public void GetPlane(vtkPlane id0)
    { GetPlane_49(id0); }

  private native void UpdatePlacement_50();
  public void UpdatePlacement()
    { UpdatePlacement_50(); }

  private native long GetNormalProperty_51();
  public vtkProperty GetNormalProperty() {
    long temp = GetNormalProperty_51();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetSelectedNormalProperty_52();
  public vtkProperty GetSelectedNormalProperty() {
    long temp = GetSelectedNormalProperty_52();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetPlaneProperty_53();
  public vtkProperty GetPlaneProperty() {
    long temp = GetPlaneProperty_53();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetSelectedPlaneProperty_54();
  public vtkProperty GetSelectedPlaneProperty() {
    long temp = GetSelectedPlaneProperty_54();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetOutlineProperty_55();
  public vtkProperty GetOutlineProperty() {
    long temp = GetOutlineProperty_55();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetSelectedOutlineProperty_56();
  public vtkProperty GetSelectedOutlineProperty() {
    long temp = GetSelectedOutlineProperty_56();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetEdgesProperty_57();
  public vtkProperty GetEdgesProperty() {
    long temp = GetEdgesProperty_57();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetEdgeColor_58(vtkLookupTable id0);
  public void SetEdgeColor(vtkLookupTable id0)
    { SetEdgeColor_58(id0); }

  private native void SetEdgeColor_59(double id0,double id1,double id2);
  public void SetEdgeColor(double id0,double id1,double id2)
    { SetEdgeColor_59(id0,id1,id2); }

  private native void SetEdgeColor_60(double id0[]);
  public void SetEdgeColor(double id0[])
    { SetEdgeColor_60(id0); }

  private native void SetBumpDistance_61(double id0);
  public void SetBumpDistance(double id0)
    { SetBumpDistance_61(id0); }

  private native double GetBumpDistanceMinValue_62();
  public double GetBumpDistanceMinValue()
    { return GetBumpDistanceMinValue_62(); }

  private native double GetBumpDistanceMaxValue_63();
  public double GetBumpDistanceMaxValue()
    { return GetBumpDistanceMaxValue_63(); }

  private native double GetBumpDistance_64();
  public double GetBumpDistance()
    { return GetBumpDistance_64(); }

  private native void BumpPlane_65(int id0,double id1);
  public void BumpPlane(int id0,double id1)
    { BumpPlane_65(id0,id1); }

  private native void PushPlane_66(double id0);
  public void PushPlane(double id0)
    { PushPlane_66(id0); }

  private native int ComputeInteractionState_67(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_67(id0,id1,id2); }

  private native void PlaceWidget_68(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_68(id0); }

  private native void BuildRepresentation_69();
  public void BuildRepresentation()
    { BuildRepresentation_69(); }

  private native void StartWidgetInteraction_70(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_70(id0); }

  private native void WidgetInteraction_71(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_71(id0); }

  private native void EndWidgetInteraction_72(double id0[]);
  public void EndWidgetInteraction(double id0[])
    { EndWidgetInteraction_72(id0); }

  private native double[] GetBounds_73();
  public double[] GetBounds()
    { return GetBounds_73(); }

  private native void GetActors_74(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_74(id0); }

  private native void ReleaseGraphicsResources_75(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_75(id0); }

  private native int RenderOpaqueGeometry_76(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_76(id0); }

  private native int RenderTranslucentPolygonalGeometry_77(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_77(id0); }

  private native int HasTranslucentPolygonalGeometry_78();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_78(); }

  private native void SetInteractionState_79(int id0);
  public void SetInteractionState(int id0)
    { SetInteractionState_79(id0); }

  private native int GetInteractionStateMinValue_80();
  public int GetInteractionStateMinValue()
    { return GetInteractionStateMinValue_80(); }

  private native int GetInteractionStateMaxValue_81();
  public int GetInteractionStateMaxValue()
    { return GetInteractionStateMaxValue_81(); }

  private native void SetRepresentationState_82(int id0);
  public void SetRepresentationState(int id0)
    { SetRepresentationState_82(id0); }

  private native int GetRepresentationState_83();
  public int GetRepresentationState()
    { return GetRepresentationState_83(); }

  public vtkImplicitPlaneRepresentation() { super(); }

  public vtkImplicitPlaneRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkImplicitPlaneRepresentation.java <==
// java wrapper for vtkImplicitPlaneRepresentation object
//

package vtk;
import vtk.*;

public class vtkImplicitPlaneRepresentation extends vtkWidgetRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetOrigin_2(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_2(id0,id1,id2); }

  private native void SetOrigin_3(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_3(id0); }

  private native double[] GetOrigin_4();
  public double[] GetOrigin()
    { return GetOrigin_4(); }

  private native void GetOrigin_5(double id0[]);
  public void GetOrigin(double id0[])
    { GetOrigin_5(id0); }

  private native void SetNormal_6(double id0,double id1,double id2);
  public void SetNormal(double id0,double id1,double id2)
    { SetNormal_6(id0,id1,id2); }

  private native void SetNormal_7(double id0[]);
  public void SetNormal(double id0[])
    { SetNormal_7(id0); }

  private native void SetNormalToCamera_8();
  public void SetNormalToCamera()
    { SetNormalToCamera_8(); }

  private native double[] GetNormal_9();
  public double[] GetNormal()
    { return GetNormal_9(); }

  private native void GetNormal_10(double id0[]);
  public void GetNormal(double id0[])
    { GetNormal_10(id0); }

  private native void SetNormalToXAxis_11(int id0);
  public void SetNormalToXAxis(int id0)
    { SetNormalToXAxis_11(id0); }

  private native int GetNormalToXAxis_12();
  public int GetNormalToXAxis()
    { return GetNormalToXAxis_12(); }

  private native void NormalToXAxisOn_13();
  public void NormalToXAxisOn()
    { NormalToXAxisOn_13(); }

  private native void NormalToXAxisOff_14();
  public void NormalToXAxisOff()
    { NormalToXAxisOff_14(); }

  private native void SetNormalToYAxis_15(int id0);
  public void SetNormalToYAxis(int id0)
    { SetNormalToYAxis_15(id0); }

  private native int GetNormalToYAxis_16();
  public int GetNormalToYAxis()
    { return GetNormalToYAxis_16(); }

  private native void NormalToYAxisOn_17();
  public void NormalToYAxisOn()
    { NormalToYAxisOn_17(); }

  private native void NormalToYAxisOff_18();
  public void NormalToYAxisOff()
    { NormalToYAxisOff_18(); }

  private native void SetNormalToZAxis_19(int id0);
  public void SetNormalToZAxis(int id0)
    { SetNormalToZAxis_19(id0); }

  private native int GetNormalToZAxis_20();
  public int GetNormalToZAxis()
    { return GetNormalToZAxis_20(); }

  private native void NormalToZAxisOn_21();
  public void NormalToZAxisOn()
    { NormalToZAxisOn_21(); }

  private native void NormalToZAxisOff_22();
  public void NormalToZAxisOff()
    { NormalToZAxisOff_22(); }

  private native void SetLockNormalToCamera_23(int id0);
  public void SetLockNormalToCamera(int id0)
    { SetLockNormalToCamera_23(id0); }

  private native int GetLockNormalToCamera_24();
  public int GetLockNormalToCamera()
    { return GetLockNormalToCamera_24(); }

  private native void LockNormalToCameraOn_25();
  public void LockNormalToCameraOn()
    { LockNormalToCameraOn_25(); }

  private native void LockNormalToCameraOff_26();
  public void LockNormalToCameraOff()
    { LockNormalToCameraOff_26(); }

  private native void SetTubing_27(int id0);
  public void SetTubing(int id0)
    { SetTubing_27(id0); }

  private native int GetTubing_28();
  public int GetTubing()
    { return GetTubing_28(); }

  private native void TubingOn_29();
  public void TubingOn()
    { TubingOn_29(); }

  private native void TubingOff_30();
  public void TubingOff()
    { TubingOff_30(); }

  private native void SetDrawPlane_31(int id0);
  public void SetDrawPlane(int id0)
    { SetDrawPlane_31(id0); }

  private native int GetDrawPlane_32();
  public int GetDrawPlane()
    { return GetDrawPlane_32(); }

  private native void DrawPlaneOn_33();
  public void DrawPlaneOn()
    { DrawPlaneOn_33(); }

  private native void DrawPlaneOff_34();
  public void DrawPlaneOff()
    { DrawPlaneOff_34(); }

  private native void SetOutlineTranslation_35(int id0);
  public void SetOutlineTranslation(int id0)
    { SetOutlineTranslation_35(id0); }

  private native int GetOutlineTranslation_36();
  public int GetOutlineTranslation()
    { return GetOutlineTranslation_36(); }

  private native void OutlineTranslationOn_37();
  public void OutlineTranslationOn()
    { OutlineTranslationOn_37(); }

  private native void OutlineTranslationOff_38();
  public void OutlineTranslationOff()
    { OutlineTranslationOff_38(); }

  private native void SetOutsideBounds_39(int id0);
  public void SetOutsideBounds(int id0)
    { SetOutsideBounds_39(id0); }

  private native int GetOutsideBounds_40();
  public int GetOutsideBounds()
    { return GetOutsideBounds_40(); }

  private native void OutsideBoundsOn_41();
  public void OutsideBoundsOn()
    { OutsideBoundsOn_41(); }

  private native void OutsideBoundsOff_42();
  public void OutsideBoundsOff()
    { OutsideBoundsOff_42(); }

  private native void SetWidgetBounds_43(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetWidgetBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetWidgetBounds_43(id0,id1,id2,id3,id4,id5); }

  private native void SetWidgetBounds_44(double id0[]);
  public void SetWidgetBounds(double id0[])
    { SetWidgetBounds_44(id0); }

  private native double[] GetWidgetBounds_45();
  public double[] GetWidgetBounds()
    { return GetWidgetBounds_45(); }

  private native void SetConstrainToWidgetBounds_46(int id0);
  public void SetConstrainToWidgetBounds(int id0)
    { SetConstrainToWidgetBounds_46(id0); }

  private native int GetConstrainToWidgetBounds_47();
  public int GetConstrainToWidgetBounds()
    { return GetConstrainToWidgetBounds_47(); }

  private native void ConstrainToWidgetBoundsOn_48();
  public void ConstrainToWidgetBoundsOn()
    { ConstrainToWidgetBoundsOn_48(); }

  private native void ConstrainToWidgetBoundsOff_49();
  public void ConstrainToWidgetBoundsOff()
    { ConstrainToWidgetBoundsOff_49(); }

  private native void SetScaleEnabled_50(int id0);
  public void SetScaleEnabled(int id0)
    { SetScaleEnabled_50(id0); }

  private native int GetScaleEnabled_51();
  public int GetScaleEnabled()
    { return GetScaleEnabled_51(); }

  private native void ScaleEnabledOn_52();
  public void ScaleEnabledOn()
    { ScaleEnabledOn_52(); }

  private native void ScaleEnabledOff_53();
  public void ScaleEnabledOff()
    { ScaleEnabledOff_53(); }

  private native void GetPolyData_54(vtkPolyData id0);
  public void GetPolyData(vtkPolyData id0)
    { GetPolyData_54(id0); }

  private native long GetPolyDataAlgorithm_55();
  public vtkPolyDataAlgorithm GetPolyDataAlgorithm() {
    long temp = GetPolyDataAlgorithm_55();

    if (temp == 0) return null;
    return (vtkPolyDataAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetPlane_56(vtkPlane id0);
  public void GetPlane(vtkPlane id0)
    { GetPlane_56(id0); }

  private native void SetPlane_57(vtkPlane id0);
  public void SetPlane(vtkPlane id0)
    { SetPlane_57(id0); }

  private native void UpdatePlacement_58();
  public void UpdatePlacement()
    { UpdatePlacement_58(); }

  private native long GetNormalProperty_59();
  public vtkProperty GetNormalProperty() {
    long temp = GetNormalProperty_59();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedNormalProperty_60();
  public vtkProperty GetSelectedNormalProperty() {
    long temp = GetSelectedNormalProperty_60();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPlaneProperty_61();
  public vtkProperty GetPlaneProperty() {
    long temp = GetPlaneProperty_61();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedPlaneProperty_62();
  public vtkProperty GetSelectedPlaneProperty() {
    long temp = GetSelectedPlaneProperty_62();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutlineProperty_63();
  public vtkProperty GetOutlineProperty() {
    long temp = GetOutlineProperty_63();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedOutlineProperty_64();
  public vtkProperty GetSelectedOutlineProperty() {
    long temp = GetSelectedOutlineProperty_64();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetEdgesProperty_65();
  public vtkProperty GetEdgesProperty() {
    long temp = GetEdgesProperty_65();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetEdgeColor_66(vtkLookupTable id0);
  public void SetEdgeColor(vtkLookupTable id0)
    { SetEdgeColor_66(id0); }

  private native void SetEdgeColor_67(double id0,double id1,double id2);
  public void SetEdgeColor(double id0,double id1,double id2)
    { SetEdgeColor_67(id0,id1,id2); }

  private native void SetEdgeColor_68(double id0[]);
  public void SetEdgeColor(double id0[])
    { SetEdgeColor_68(id0); }

  private native void SetBumpDistance_69(double id0);
  public void SetBumpDistance(double id0)
    { SetBumpDistance_69(id0); }

  private native double GetBumpDistanceMinValue_70();
  public double GetBumpDistanceMinValue()
    { return GetBumpDistanceMinValue_70(); }

  private native double GetBumpDistanceMaxValue_71();
  public double GetBumpDistanceMaxValue()
    { return GetBumpDistanceMaxValue_71(); }

  private native double GetBumpDistance_72();
  public double GetBumpDistance()
    { return GetBumpDistance_72(); }

  private native void BumpPlane_73(int id0,double id1);
  public void BumpPlane(int id0,double id1)
    { BumpPlane_73(id0,id1); }

  private native void PushPlane_74(double id0);
  public void PushPlane(double id0)
    { PushPlane_74(id0); }

  private native int ComputeInteractionState_75(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_75(id0,id1,id2); }

  private native void PlaceWidget_76(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_76(id0); }

  private native void BuildRepresentation_77();
  public void BuildRepresentation()
    { BuildRepresentation_77(); }

  private native void StartWidgetInteraction_78(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_78(id0); }

  private native void WidgetInteraction_79(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_79(id0); }

  private native void EndWidgetInteraction_80(double id0[]);
  public void EndWidgetInteraction(double id0[])
    { EndWidgetInteraction_80(id0); }

  private native double[] GetBounds_81();
  public double[] GetBounds()
    { return GetBounds_81(); }

  private native void GetActors_82(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_82(id0); }

  private native void ReleaseGraphicsResources_83(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_83(id0); }

  private native int RenderOpaqueGeometry_84(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_84(id0); }

  private native int RenderTranslucentPolygonalGeometry_85(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_85(id0); }

  private native int HasTranslucentPolygonalGeometry_86();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_86(); }

  private native void SetInteractionState_87(int id0);
  public void SetInteractionState(int id0)
    { SetInteractionState_87(id0); }

  private native int GetInteractionStateMinValue_88();
  public int GetInteractionStateMinValue()
    { return GetInteractionStateMinValue_88(); }

  private native int GetInteractionStateMaxValue_89();
  public int GetInteractionStateMaxValue()
    { return GetInteractionStateMaxValue_89(); }

  private native void SetRepresentationState_90(int id0);
  public void SetRepresentationState(int id0)
    { SetRepresentationState_90(id0); }

  private native int GetRepresentationState_91();
  public int GetRepresentationState()
    { return GetRepresentationState_91(); }

  public vtkImplicitPlaneRepresentation() { super(); }

  public vtkImplicitPlaneRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
